pub struct SortedSetAddOptions {
pub if_not_exists: bool,
pub if_exists: bool,
pub greater_than: bool,
pub less_than: bool,
pub changed: bool,
}Expand description
ZADD options. The server refuses NX with XX, GT, or LT, and GT with LT.
Fields
if_not_exists: boolOnly add new members (NX).
if_exists: boolOnly update existing members (XX).
greater_than: boolOnly update when the new score is greater (GT). A missing member is still added.
less_than: boolOnly update when the new score is lower (LT). A missing member is still added.
changed: boolCount changed members as well as new ones (CH).